ZlibStream

Struct ZlibStream 

pub(super) struct ZlibStream {
    state: Box<Decompressor>,
    started: bool,
    ignore_adler32: bool,
}
Ergonomics wrapper around miniz_oxide::inflate::stream for zlib compressed data.

Fields

state: Box<Decompressor>

Current decoding state.

started: bool

If there has been a call to decompress already.

ignore_adler32: bool

Ignore and do not calculate the Adler-32 checksum. Defaults to true.

This flag overrides TINFL_FLAG_COMPUTE_ADLER32.

This flag should not be modified after decompression has started.

Implementations

Source

impl ZlibStream

pub(crate) fn new() -> Self

pub(crate) fn reset(&mut self)

pub(crate) fn set_ignore_adler32(&mut self, flag: bool) -> bool

Set the ignore_adler32 flag and return true if the flag was successfully set.

The default is true.

This flag cannot be modified after decompression has started until the ZlibStream is reset.

pub(crate) fn ignore_adler32(&self) -> bool

Return the ignore_adler32 flag.

pub(crate) fn decompress( &mut self, data: &[u8], image_data: &mut UnfilterBuf<'_>, ) -> Result<usize, DecodingError>

Fill the decoded buffer as far as possible from data. On success returns the number of consumed input bytes.

pub(crate) fn finish( &mut self, image_data: &mut UnfilterBuf<'_>, ) -> Result<bool, DecodingError>

Output any remaining buffered data within the decompressor.

Returns Ok(true) if all data has been decompressed and there is no more data that will be produced, or Ok(false) if there’s potentially more output.

Returns Err if the zlib stream is corrupt or truncated too early.